==> docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2/luna-sdk_alma_rel_v.5.31.2/doc/fsdk/html/search/enumvalues_b.js <==
var searchData=
[
  ['natural',['Natural',['../group___estimator_group.html#gga2f7dd5b6147940ccba6ff5b29be565aba2bd8ab451a35759c5737128e35c8011a',1,'fsdk']]],
  ['negative',['Negative',['../structfsdk_1_1_one_p_p_e_estimation.html#a080da361dbc19f0ba247c6363a15fb65affb9356ff2b7da85c75c92fa7ea03b8b',1,'fsdk::OnePPEEstimation']]],
  ['nir',['NIR',['../namespacefsdk.html#a2cd10d6257c328c01b7d7296938881f8aac46d1e7cde34e4a9b473eb8a9d8c443',1,'fsdk']]],
  ['nodocumentelement',['NoDocumentElement',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a655f7706c6b80b169803c2854e43f207',1,'fsdk::ISettingsProvider']]],
  ['nofight',['NoFight',['../structfsdk_1_1_fights_estimation.html#aea94b3828eb9c964a7fd0b07f4f1fe05a757f0a89dfcb5fdf891482021f47a994',1,'fsdk::FightsEstimation']]],
  ['nofisheyeeffect',['NoFishEyeEffect',['../group___estimator_group.html#gga364aa8a6ba6e9e6ca82390a6064d23c6af8c91ef40f68c6239e38e7fda2824b6a',1,'fsdk']]],
  ['noglasses',['NoGlasses',['../group___estimator_group.html#ggaa45cbedc4e8044e57d4b88144be36478ad6e6ea79756eab21131ccaa8bb2c1634',1,'fsdk']]],
  ['nohair',['NoHair',['../group___estimator_group.html#ggac40caf1f72fab400cd2460f9ac2237c0a3c46cd1abe78150a3720128573b92ed8',1,'fsdk']]],
  ['nomask',['NoMask',['../group___estimator_group.html#gga7a832d1cd24208a884d83c7b989e1df3af50feb187f8ec40ffbe7d4eed016abc0',1,'fsdk::NoMask()'],['../group___estimator_group.html#gga8e6d98deb6ca721b047ae0635017bdd4af50feb187f8ec40ffbe7d4eed016abc0',1,'fsdk::NoMask()']]],
  ['non',['Non',['../structfsdk_1_1_head_pose_estimation.html#aa2121a6759ada82ee49750f4922fd9a7a24492e9ec0700fa260acd0c5c15f22d1',1,'fsdk::HeadPoseEstimation']]],
  ['none',['None',['../group___estimator_group.html#gga1021a188b3259b154cb0dd34dbf70aaaa6adf97f83acf6453d4a6a4b1070f3754',1,'fsdk']]],
  ['nonnatural',['NonNatural',['../group___estimator_group.html#gga2f7dd5b6147940ccba6ff5b29be565abaf5c829a38c7e64b2dd821a9192c05926',1,'fsdk']]],
  ['nonportrait',['NonPortrait',['../group___estimator_group.html#gga528fc22b5cd79e51784fedb1539b536ba80bf0760bf79f342b816fc637f236647',1,'fsdk']]],
  ['nonred',['NonRed',['../group___estimator_group.html#gga9a9ac78ca6a5f95037c789d0cf2776c5a6457463779b9ee3a55789834b5a34582',1,'fsdk']]],
  ['nonreliable',['NonReliable',['../group___estimator_group.html#gga088edfc69279e44300259c1e80b75037ac91ca4f3564e3ebf30abdb46e70149df',1,'fsdk']]],
  ['nonsolid',['NonSolid',['../group___estimator_group.html#gga138fe26fec23c695363e62a47a5df8e5ac3b003da334b6b87591a15390d18e48c',1,'fsdk']]],
  ['nonwaitable',['NonWaitable',['../namespacefsdk.html#ab7f8be96a87fd4e85bd762a7f8f8f8fba3b80f1e3131f25efad47938c5e9c66fc',1,'fsdk']]],
  ['nose',['Nose',['../group___occlusion_estimator_group.html#gga8b3ddce447c4f06eb4413fc267796a26a4432170f33a27181720d70ee7d6d2dee',1,'fsdk']]],
  ['nosignature',['NoSignature',['../structfsdk_1_1_i_serializable_object.html#ac02b734576139d792a928b0a9ade7d79abe2164cbc91b390163c0c9af3448acf6',1,'fsdk::ISerializableObject']]],
  ['notfulfilled',['NotFulfilled',['../namespacefsdk.html#ab7f8be96a87fd4e85bd762a7f8f8f8fba1f044538a6ed1853dd8ddd097b77fd90',1,'fsdk']]],
  ['notimplemented',['NotImplemented',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a997ca4ce119685f40f03a9a8a6c5346e',1,'fsdk']]],
  ['notoccluded',['NotOccluded',['../group___occlusion_estimator_group.html#gga843192d016e3a14dc5c9a3ef75d5124faea08b0fca9e64bf979f3e2ea0477eaa1',1,'fsdk']]],
  ['notpromised',['NotPromised',['../namespacefsdk.html#ab7f8be96a87fd4e85bd762a7f8f8f8fba6eea7f630714b872a5f9f60ecb6b02b2',1,'fsdk']]]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0/luna-sdk_alma_rel_v.5.34.0/doc/fsdk/html/search/enumvalues_b.js <==
var searchData=
[
  ['natural',['Natural',['../group___estimator_group.html#gga2f7dd5b6147940ccba6ff5b29be565aba2bd8ab451a35759c5737128e35c8011a',1,'fsdk']]],
  ['neckcovered',['NeckCovered',['../structfsdk_1_1_neck_occlusion_estimation.html#a3f3ce147b8819b2d8dcf241811bc870bab6335f179685defcb77596d72a3e2a38',1,'fsdk::NeckOcclusionEstimation']]],
  ['neckopen',['NeckOpen',['../structfsdk_1_1_neck_occlusion_estimation.html#a3f3ce147b8819b2d8dcf241811bc870bacf28d3e272116feb6fe3b2d436972f95',1,'fsdk::NeckOcclusionEstimation']]],
  ['neckunknown',['NeckUnknown',['../structfsdk_1_1_neck_occlusion_estimation.html#a3f3ce147b8819b2d8dcf241811bc870bafe41bc3e6b094cdfe9d03086c0aa366a',1,'fsdk::NeckOcclusionEstimation']]],
  ['negative',['Negative',['../structfsdk_1_1_one_p_p_e_estimation.html#a080da361dbc19f0ba247c6363a15fb65affb9356ff2b7da85c75c92fa7ea03b8b',1,'fsdk::OnePPEEstimation']]],
  ['nir',['NIR',['../namespacefsdk.html#a2cd10d6257c328c01b7d7296938881f8aac46d1e7cde34e4a9b473eb8a9d8c443',1,'fsdk']]],
  ['nodocumentelement',['NoDocumentElement',['../structfsdk_1_1_i_settings_provider.html#a645a0b8fb7db4e4d2ddc5bdb68a5cad5a655f7706c6b80b169803c2854e43f207',1,'fsdk::ISettingsProvider']]],
  ['nofight',['NoFight',['../structfsdk_1_1_fights_estimation.html#aea94b3828eb9c964a7fd0b07f4f1fe05a757f0a89dfcb5fdf891482021f47a994',1,'fsdk::FightsEstimation']]],
  ['nofisheyeeffect',['NoFishEyeEffect',['../group___estimator_group.html#gga364aa8a6ba6e9e6ca82390a6064d23c6af8c91ef40f68c6239e38e7fda2824b6a',1,'fsdk']]],
  ['noglasses',['NoGlasses',['../group___estimator_group.html#ggaa45cbedc4e8044e57d4b88144be36478ad6e6ea79756eab21131ccaa8bb2c1634',1,'fsdk']]],
  ['nohair',['NoHair',['../group___estimator_group.html#ggac40caf1f72fab400cd2460f9ac2237c0a3c46cd1abe78150a3720128573b92ed8',1,'fsdk']]],
  ['nomask',['NoMask',['../group___estimator_group.html#gga7a832d1cd24208a884d83c7b989e1df3af50feb187f8ec40ffbe7d4eed016abc0',1,'fsdk::NoMask()'],['../group___estimator_group.html#gga8e6d98deb6ca721b047ae0635017bdd4af50feb187f8ec40ffbe7d4eed016abc0',1,'fsdk::NoMask()']]],
  ['non',['Non',['../structfsdk_1_1_head_pose_estimation.html#aa2121a6759ada82ee49750f4922fd9a7a24492e9ec0700fa260acd0c5c15f22d1',1,'fsdk::HeadPoseEstimation']]],
  ['none',['None',['../group___estimator_group.html#gga1021a188b3259b154cb0dd34dbf70aaaa6adf97f83acf6453d4a6a4b1070f3754',1,'fsdk']]],
  ['nonnatural',['NonNatural',['../group___estimator_group.html#gga2f7dd5b6147940ccba6ff5b29be565abaf5c829a38c7e64b2dd821a9192c05926',1,'fsdk']]],
  ['nonportrait',['NonPortrait',['../group___estimator_group.html#gga528fc22b5cd79e51784fedb1539b536ba80bf0760bf79f342b816fc637f236647',1,'fsdk']]],
  ['nonred',['NonRed',['../group___estimator_group.html#gga9a9ac78ca6a5f95037c789d0cf2776c5a6457463779b9ee3a55789834b5a34582',1,'fsdk']]],
  ['nonreliable',['NonReliable',['../group___estimator_group.html#gga088edfc69279e44300259c1e80b75037ac91ca4f3564e3ebf30abdb46e70149df',1,'fsdk']]],
  ['nonsolid',['NonSolid',['../group___estimator_group.html#gga138fe26fec23c695363e62a47a5df8e5ac3b003da334b6b87591a15390d18e48c',1,'fsdk']]],
  ['nonwaitable',['NonWaitable',['../namespacefsdk.html#ab7f8be96a87fd4e85bd762a7f8f8f8fba3b80f1e3131f25efad47938c5e9c66fc',1,'fsdk']]],
  ['nose',['Nose',['../group___occlusion_estimator_group.html#gga8b3ddce447c4f06eb4413fc267796a26a4432170f33a27181720d70ee7d6d2dee',1,'fsdk']]],
  ['noshoulderstraps',['NoShoulderStraps',['../structfsdk_1_1_duty_uniform_estimation.html#aa7c09a87e1b87f6304ae709243cb1457a45c59b35a0a59116e6b143c6f5d6b34c',1,'fsdk::DutyUniformEstimation']]],
  ['nosignature',['NoSignature',['../structfsdk_1_1_i_serializable_object.html#ac02b734576139d792a928b0a9ade7d79abe2164cbc91b390163c0c9af3448acf6',1,'fsdk::ISerializableObject']]],
  ['notfulfilled',['NotFulfilled',['../namespacefsdk.html#ab7f8be96a87fd4e85bd762a7f8f8f8fba1f044538a6ed1853dd8ddd097b77fd90',1,'fsdk']]],
  ['notimplemented',['NotImplemented',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a997ca4ce119685f40f03a9a8a6c5346e',1,'fsdk']]],
  ['notoccluded',['NotOccluded',['../group___occlusion_estimator_group.html#gga843192d016e3a14dc5c9a3ef75d5124faea08b0fca9e64bf979f3e2ea0477eaa1',1,'fsdk']]],
  ['notpromised',['NotPromised',['../namespacefsdk.html#ab7f8be96a87fd4e85bd762a7f8f8f8fba6eea7f630714b872a5f9f60ecb6b02b2',1,'fsdk']]]
];
